@@ -1084,6 +1084,14 @@ class Deploy(command.Command):
                    'deployed services are running right after their '
                    'activation. Defaults to False.')
         )
+        parser.add_argument(
+            '--ansible-forks',
+            action='store',
+            default=None,
+            type=int,
+            help=_('The number of Ansible forks to use for the'
+                   ' config-download ansible-playbook command.')
+        )
 
         stack_action_group = parser.add_mutually_exclusive_group()
 
@@ -1326,6 +1334,7 @@ class Deploy(command.Command):
                             workdir=self.ansible_dir,
                             verbosity=utils.playbook_verbosity(self=self),
                             extra_env_variables=extra_env_var,
+                            forks=parsed_args.ansible_forks,
                             **operation)
             is_complete = True
         finally:
@@ -1401,6 +1410,12 @@ class Deploy(command.Command):
 
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
+        if parsed_args.deployment_user == 'root':
+            self.log.warning(
+                _("[WARNING] Deployment user is set to 'root'. This may cause "
+                  "some deployment files to be located in /root. Please use "
+                  "--deployment-user to specify the user you are deploying "
+                  "with."))
         try:
             if parsed_args.standalone:
                 self._standalone_deploy(parsed_args)
